@@ -109,8 +109,7 @@ class Usuario(models.Model):
     email = models.EmailField(db_column="usuario_email")
     confirmado = models.BooleanField(db_column="usuario_confirmado", default=False)
 
-    contas = models.ManyToManyField('plataforma.Conta', related_name="usuarios", through="ContaUsuario")
-    # conta_id = models.ManyToManyField('Conta', through="ContaUsuario")
+    conta_id = models.ManyToManyField('Conta', related_name="usuarios", through="ContaUsuario")
 
     class Meta:
         db_table = u"plataforma\".\"tb_usuario"
